@@ -2,5 +2,5 @@ from . import rest_api
 from . import ngrok
 
 from .rest_api import rest_api
-from .rest_api image_to_base64
+from .rest_api import image_to_base64
 from .ngrok import run_with_ngrok
